@@ -1,5 +1,5 @@
 # fields, Tools for spatial data
-# Copyright 2004-2011, Institute for Mathematics Applied Geosciences
+# Copyright 2004-2013, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
 "summary.sreg" <- function(object, digits = 4, ...) {
@@ -21,6 +21,6 @@
     summary$adjr2 <- 1 - ((length(x$residuals) - 1)/(length(x$residuals) - 
         x$eff.df)) * (1 - hold)
     summary$digits <- digits
-    summary$sum.gcv.lambda <- summary.gcv.sreg(x, x$lambda)
+    summary$sum.gcv.lambda <- summaryGCV.sreg(x, x$lambda)
     summary
 }
